#  Copyright (C) 2021
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Mike Orlov <m.orlov@abm-jsc.ru>
#

from typing import Any


def is_none(val: Any) -> bool:
    return val is None


def is_not_none(val: Any) -> bool:
    return val is not None
